@@ -58,7 +58,7 @@ def identifier_list_cmp(a, b):
 class Version(object):
 
     version_re = re.compile('^(\d+)\.(\d+)\.(\d+)(?:-([0-9a-zA-Z.-]+))?(?:\+([0-9a-zA-Z.-]+))?$')
-    partial_version_re = re.compile('^(\d+)(?:\.(\d+)(?:\.(\d+)(?:-([0-9a-zA-Z.-]+))?(?:\+([0-9a-zA-Z.-]+))?)?)?$')
+    partial_version_re = re.compile('^(\d+)\.(\d+)\.(\d+)(?:-([0-9a-zA-Z.-]*))?(?:\+([0-9a-zA-Z.-]*))?$')
 
     def __init__(self, version_string, partial=False):
         major, minor, patch, prerelease, build = self.parse(version_string, partial)
@@ -88,23 +88,17 @@ class Version(object):
         major, minor, patch, prerelease, build = match.groups()
 
         major = int(major)
-
-        if minor is None:
-            return (major, None, None, None, None)
-        else:
-            minor = int(minor)
-
-        if patch is None:
-            return (major, minor, None, None, None)
-        else:
-            patch = int(patch)
+        minor = int(minor)
+        patch = int(patch)
 
         if prerelease is None:
-            if partial and not build:
+            if partial and (build is None):
                 # No build info, strip here
                 return (major, minor, patch, None, None)
             else:
                 prerelease = ()
+        elif prerelease == '':
+            prerelease = ()
         else:
             prerelease = tuple(prerelease.split('.'))
 
@@ -113,6 +107,8 @@ class Version(object):
                 build = None
             else:
                 build = ()
+        elif build == '':
+            build = ()
         else:
             build = tuple(build.split('.'))
 
@@ -122,16 +118,11 @@ class Version(object):
         return iter((self.major, self.minor, self.patch, self.prerelease, self.build))
 
     def __str__(self):
-        if self.minor is None:
-            return '%d' % self.major
-        elif self.patch is None:
-            return '%d.%d' % (self.major, self.minor)
-
         version = '%d.%d.%d' % (self.major, self.minor, self.patch)
 
-        if self.prerelease:
+        if self.prerelease or (self.partial and self.prerelease == () and self.build is None):
             version = '%s-%s' % (version, '.'.join(self.prerelease))
-        if self.build:
+        if self.build or (self.partial and self.build == ()):
             version = '%s+%s' % (version, '.'.join(self.build))
         return version
 
@@ -236,7 +227,7 @@ class Version(object):
         return 0
 
 
-class Spec(object):
+class SpecItem(object):
     """A requirement specification."""
 
     KIND_LT = '<'
@@ -255,19 +246,7 @@ class Spec(object):
         KIND_NEQ,
     )
 
-    KIND_LTE_LOOSE = '<~'
-    KIND_EQ_LOOSE = '~='
-    KIND_GTE_LOOSE = '>~'
-    KIND_NEQ_LOOSE = '!~'
-
-    LOOSE_KINDS = (
-        KIND_LTE_LOOSE,
-        KIND_EQ_LOOSE,
-        KIND_GTE_LOOSE,
-        KIND_NEQ_LOOSE,
-    )
-
-    re_spec = re.compile(r'^(<|<=|==|>=|>|!=|<~|>~|~=|!~)(\d.*)$')
+    re_spec = re.compile(r'^(<|<=|==|>=|>|!=)(\d.*)$')
 
     def __init__(self, requirement_string):
         kind, spec = self.parse(requirement_string)
@@ -284,38 +263,33 @@ class Spec(object):
             raise ValueError("Invalid requirement specification: %r" % requirement_string)
 
         kind, version = match.groups()
-        spec = Version(version, partial=(kind in cls.LOOSE_KINDS))
+        spec = Version(version, partial=True)
         return (kind, spec)
 
     def match(self, version):
         if self.kind == self.KIND_LT:
             return version < self.spec
-        elif self.kind in (self.KIND_LTE, self.KIND_LTE_LOOSE):
+        elif self.kind == self.KIND_LTE:
             return version <= self.spec
-        elif self.kind in (self.KIND_EQUAL, self.KIND_EQ_LOOSE):
+        elif self.kind == self.KIND_EQUAL:
             return version == self.spec
-        elif self.kind in (self.KIND_GTE, self.KIND_GTE_LOOSE):
+        elif self.kind == self.KIND_GTE:
             return version >= self.spec
         elif self.kind == self.KIND_GT:
             return version > self.spec
-        elif self.kind in (self.KIND_NEQ, self.KIND_NEQ_LOOSE):
+        elif self.kind == self.KIND_NEQ:
             return version != self.spec
         else:  # pragma: no cover
             raise ValueError('Unexpected match kind: %r' % self.kind)
 
-    def __contains__(self, version):
-        if isinstance(version, Version):
-            return self.match(version)
-        return False
-
     def __str__(self):
         return '%s%s' % (self.kind, self.spec)
 
     def __repr__(self):
-        return '<Spec: %s %r>' % (self.kind, self.spec)
+        return '<SpecItem: %s %r>' % (self.kind, self.spec)
 
     def __eq__(self, other):
-        if not isinstance(other, Spec):
+        if not isinstance(other, SpecItem):
             return NotImplemented
         return self.kind == other.kind and self.spec == other.spec
 
@@ -323,7 +297,7 @@ class Spec(object):
         return hash((self.kind, self.spec))
 
 
-class SpecList(object):
+class Spec(object):
     def __init__(self, *specs_strings):
         subspecs = [self.parse(spec) for spec in specs_strings]
         self.specs = sum(subspecs, ())
@@ -331,9 +305,10 @@ class SpecList(object):
     @classmethod
     def parse(self, specs_string):
         spec_texts = specs_string.split(',')
-        return tuple(Spec(spec_text) for spec_text in spec_texts)
+        return tuple(SpecItem(spec_text) for spec_text in spec_texts)
 
     def match(self, version):
+        """Check whether a Version satisfies the Spec."""
         return all(spec.match(version) for spec in self.specs)
 
     def __contains__(self, version):
@@ -348,10 +323,10 @@ class SpecList(object):
         return ','.join(str(spec) for spec in self.specs)
 
     def __repr__(self):
-        return '<SpecList: %r>' % (self.specs,)
+        return '<Spec: %r>' % (self.specs,)
 
     def __eq__(self, other):
-        if not isinstance(other, SpecList):
+        if not isinstance(other, Spec):
             return NotImplemented
 
         return set(self.specs) == set(other.specs)
